==> winnie-0.1.46.tgz: package/winnie-widget.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var _createClass = require('@babel/runtime/helpers/createClass');
var HolyGrailPane = require('kenga-containers/holy-grail-pane');
var ScrollPane = require('kenga-containers/scroll-pane');
var SplitPane = require('kenga-containers/split-pane');
var GridPane = require('kenga-containers/grid-pane');
var DataGrid = require('kenga-grid/grid');
var ColumnNode = require('kenga-grid/columns/column-node');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var _createClass__default = /*#__PURE__*/_interopDefaultLegacy(_createClass);
var HolyGrailPane__default = /*#__PURE__*/_interopDefaultLegacy(HolyGrailPane);
var ScrollPane__default = /*#__PURE__*/_interopDefaultLegacy(ScrollPane);
var SplitPane__default = /*#__PURE__*/_interopDefaultLegacy(SplitPane);
var GridPane__default = /*#__PURE__*/_interopDefaultLegacy(GridPane);
var DataGrid__default = /*#__PURE__*/_interopDefaultLegacy(DataGrid);
var ColumnNode__default = /*#__PURE__*/_interopDefaultLegacy(ColumnNode);

var WidgetWrapper = /*#__PURE__*/function () {
  function WidgetWrapper(w, name, defaultInstance, onRename) {
    _classCallCheck__default['default'](this, WidgetWrapper);

    this.delegate = w;
    this._name = name;
    this.onRename = onRename;
    this.defaultInstance = defaultInstance;
    w['winnie.wrapper'] = this;
  }

  _createClass__default['default'](WidgetWrapper, [{
    key: "name",
    get: function get() {
      return this._name;
    },
    set: function set(v) {
      if (this._name !== v) {
        this.onRename(v);
      }
    }
  }, {
    key: "full",
    get: function get() {
      if (this.delegate instanceof HolyGrailPane__default['default']) {
        return this.count >= 5;
      } else if (this.delegate instanceof ScrollPane__default['default']) {
        return this.count >= 1;
      } else if (this.delegate instanceof SplitPane__default['default']) {
        return this.count >= 2;
      } else if (this.delegate instanceof GridPane__default['default']) {
        return this.count >= this.delegate.rows * this.delegate.columns;
      } else {
        return false;
      }
    }
  }, {
    key: "parent",
    get: function get() {
      var _this = this;

      var delegateParent = function () {
        if (_this.delegate instanceof ColumnNode__default['default']) {
          if (_this.delegate.parent == null) {
            return _this.delegate.column.grid;
          } else {
            return _this.delegate.parent;
          }
        } else {
          return _this.delegate.parent;
        }
      }();

      return delegateParent ? delegateParent['winnie.wrapper'] : null;
    }
  }, {
    key: "children",
    get: function get() {
      var _this2 = this;

      var self = this;
      return function () {
        if (self.delegate instanceof HolyGrailPane__default['default']) {
          return [self.delegate.header, self.delegate.leftSide, self.delegate.content, self.delegate.rightSide, self.delegate.footer];
        } else if (self.delegate instanceof ScrollPane__default['default']) {
          return [self.delegate.view];
        } else if (self.delegate instanceof SplitPane__default['default']) {
          return [self.delegate.first, self.delegate.second];
        } else if (self.delegate instanceof GridPane__default['default']) {
          var children = [];

          for (var row = 0; row < _this2.delegate.rows; row++) {
            for (var column = 0; column < _this2.delegate.columns; column++) {
              children.push(_this2.delegate.child(row, column));
            }
          }

          return children;
        } else if (self.delegate instanceof DataGrid__default['default']) {
          return self.delegate.header;
        } else if (self.delegate instanceof ColumnNode__default['default']) {
          return self.delegate.children;
        } else {
          return self.delegate.children ? self.delegate.children() : [];
        }
      }().filter(function (item) {
        return !!item;
      }).map(function (child) {
        return child['winnie.wrapper'];
      });
    }
  }, {
    key: "count",
    get: function get() {
      if (this.delegate instanceof DataGrid__default['default'] || this.delegate instanceof ColumnNode__default['default']) {
        return this.children.length;
      } else {
        return this.delegate.count;
      }
    }
  }, {
    key: "indexOf",
    value: function indexOf(subject) {
      if (this.delegate instanceof DataGrid__default['default'] || this.delegate instanceof ColumnNode__default['default']) {
        return this.children.indexOf(subject);
      } else {
        if (this.delegate instanceof HolyGrailPane__default['default']) {
          if (subject.delegate === this.delegate.header) {
            return 0;
          } else if (subject.delegate === this.delegate.leftSide) {
            return 1;
          } else if (subject.delegate === this.delegate.content) {
            return 2;
          } else if (subject.delegate === this.delegate.rightSide) {
            return 3;
          } else if (subject.delegate === this.delegate.footer) {
            return 4;
          } else {
            return -1;
          }
        } else if (this.delegate instanceof ScrollPane__default['default']) {
          if (subject.delegate === this.delegate.view) {
            return 0;
          } else {
            return -1;
          }
        } else if (this.delegate instanceof SplitPane__default['default']) {
          if (subject.delegate === this.delegate.first) {
            return 0;
          } else if (subject.delegate === this.delegate.second) {
            return 1;
          } else {
            return -1;
          }
        } else if (this.delegate instanceof GridPane__default['default']) {
          return this.children.indexOf(subject);
        } else {
          return this.delegate.indexOf(subject.delegate);
        }
      }
    }
  }, {
    key: "add",
    value: function add(subject, index) {
      if (this.delegate instanceof DataGrid__default['default'] || this.delegate instanceof ColumnNode__default['default']) {
        this.delegate.insertColumnNode(index, subject.delegate);
      } else if (this.delegate instanceof HolyGrailPane__default['default']) {
        var children = this.children;
        children.splice(index, 0, subject);
        this.delegate.clear();
        this.delegate.header = children.length > 0 ? children[0].delegate : null;
        this.delegate.leftSide = children.length > 1 ? children[1].delegate : null;
        this.delegate.content = children.length > 2 ? children[2].delegate : null;
        this.delegate.rightSide = children.length > 3 ? children[3].delegate : null;
        this.delegate.footer = children.length > 4 ? children[4].delegate : null;
      } else if (this.delegate instanceof ScrollPane__default['default']) {
        this.delegate.view = subject.delegate;
      } else if (this.delegate instanceof SplitPane__default['default']) {
        var _children = this.children;

        _children.splice(index, 0, subject);

        this.delegate.clear();
        this.delegate.first = _children.length > 0 ? _children[0].delegate : null;
        this.delegate.second = _children.length > 1 ? _children[1].delegate : null;
      } else if (this.delegate instanceof GridPane__default['default']) {
        var _children2 = this.children;

        _children2.splice(index, 0, subject);

        this.delegate.clear();

        for (var row = 0; row < this.delegate.rows; row++) {
          for (var column = 0; column < this.delegate.columns; column++) {
            var gIndex = row * this.delegate.columns + column;

            if (gIndex < _children2.length) {
              this.delegate.add(_children2[gIndex].delegate, row, column);
            }
          }
        }
      } else {
        this.delegate.add(subject.delegate, index);
      }
    }
  }, {
    key: "remove",
    value: function remove(index) {
      if (this.delegate instanceof DataGrid__default['default'] || this.delegate instanceof ColumnNode__default['default']) {
        this.delegate.removeColumnNodeAt(index);
      } else if (this.delegate instanceof HolyGrailPane__default['default']) {
        var children = this.children;
        children.splice(index, 1);
        this.delegate.header = this.delegate.leftSide = this.delegate.content = this.delegate.rightSide = this.delegate.footer = null;
        this.delegate.header = children.length > 0 ? children[0].delegate : null;
        this.delegate.leftSide = children.length > 1 ? children[1].delegate : null;
        this.delegate.content = children.length > 2 ? children[2].delegate : null;
        this.delegate.rightSide = children.length > 3 ? children[3].delegate : null;
        this.delegate.footer = children.length > 4 ? children[4].delegate : null;
      } else if (this.delegate instanceof ScrollPane__default['default']) {
        this.delegate.view = null;
      } else if (this.delegate instanceof SplitPane__default['default']) {
        var _children3 = this.children;

        _children3.splice(index, 1);

        this.delegate.first = this.delegate.second = null;
        this.delegate.first = _children3.length > 0 ? _children3[0].delegate : null;
        this.delegate.second = _children3.length > 1 ? _children3[1].delegate : null;
      } else if (this.delegate instanceof GridPane__default['default']) {
        var _children4 = this.children;

        _children4.splice(index, 1);

        this.delegate.clear();

        for (var row = 0; row < this.delegate.rows; row++) {
          for (var column = 0; column < this.delegate.columns; column++) {
            var gIndex = row * this.delegate.columns + column;

            if (gIndex < _children4.length) {
              this.delegate.add(_children4[gIndex].delegate, row, column);
            }
          }
        }
      } else {
        this.delegate.remove(index);
      }
    }
  }]);

  return WidgetWrapper;
}();

module.exports = WidgetWrapper;

==> winnie-0.1.55.tgz: package/winnie-widget.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var _createClass = require('@babel/runtime/helpers/createClass');
var HolyGrailPane = require('kenga-containers/holy-grail-pane');
var ScrollPane = require('kenga-containers/scroll-pane');
var SplitPane = require('kenga-containers/split-pane');
var DataGrid = require('kenga-grid/grid');
var ColumnNode = require('kenga-grid/columns/column-node');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var _createClass__default = /*#__PURE__*/_interopDefaultLegacy(_createClass);
var HolyGrailPane__default = /*#__PURE__*/_interopDefaultLegacy(HolyGrailPane);
var ScrollPane__default = /*#__PURE__*/_interopDefaultLegacy(ScrollPane);
var SplitPane__default = /*#__PURE__*/_interopDefaultLegacy(SplitPane);
var DataGrid__default = /*#__PURE__*/_interopDefaultLegacy(DataGrid);
var ColumnNode__default = /*#__PURE__*/_interopDefaultLegacy(ColumnNode);

var WidgetWrapper = /*#__PURE__*/function () {
  function WidgetWrapper(w, name, defaultInstance, onRename) {
    _classCallCheck__default["default"](this, WidgetWrapper);

    this.delegate = w;
    this._name = name;
    this.onRename = onRename;
    this.defaultInstance = defaultInstance;
    w['winnie.wrapper'] = this;
  }

  _createClass__default["default"](WidgetWrapper, [{
    key: "name",
    get: function get() {
      return this._name;
    },
    set: function set(v) {
      if (this._name !== v) {
        this.onRename(v);
      }
    }
  }, {
    key: "full",
    get: function get() {
      if (this.delegate instanceof HolyGrailPane__default["default"]) {
        return this.count >= 5;
      } else if (this.delegate instanceof ScrollPane__default["default"]) {
        return this.count >= 1;
      } else if (this.delegate instanceof SplitPane__default["default"]) {
        return this.count >= 2;
      } else {
        return false;
      }
    }
  }, {
    key: "parent",
    get: function get() {
      var _this = this;

      var delegateParent = function () {
        if (_this.delegate instanceof ColumnNode__default["default"]) {
          if (_this.delegate.parent == null) {
            return _this.delegate.column.grid;
          } else {
            return _this.delegate.parent;
          }
        } else {
          return _this.delegate.parent;
        }
      }();

      return delegateParent ? delegateParent['winnie.wrapper'] : null;
    }
  }, {
    key: "children",
    get: function get() {
      var self = this;
      return function () {
        if (self.delegate instanceof HolyGrailPane__default["default"]) {
          return [self.delegate.header, self.delegate.leftSide, self.delegate.content, self.delegate.rightSide, self.delegate.footer];
        } else if (self.delegate instanceof ScrollPane__default["default"]) {
          return [self.delegate.view];
        } else if (self.delegate instanceof SplitPane__default["default"]) {
          return [self.delegate.first, self.delegate.second];
        } else if (self.delegate instanceof DataGrid__default["default"]) {
          return self.delegate.header;
        } else if (self.delegate instanceof ColumnNode__default["default"]) {
          return self.delegate.children;
        } else {
          return self.delegate.children ? self.delegate.children() : [];
        }
      }().filter(function (item) {
        return !!item;
      }).map(function (child) {
        return child['winnie.wrapper'];
      });
    }
  }, {
    key: "count",
    get: function get() {
      if (this.delegate instanceof DataGrid__default["default"] || this.delegate instanceof ColumnNode__default["default"]) {
        return this.children.length;
      } else {
        return this.delegate.count;
      }
    }
  }, {
    key: "indexOf",
    value: function indexOf(subject) {
      if (this.delegate instanceof DataGrid__default["default"] || this.delegate instanceof ColumnNode__default["default"]) {
        return this.children.indexOf(subject);
      } else {
        if (this.delegate instanceof HolyGrailPane__default["default"]) {
          if (subject.delegate === this.delegate.header) {
            return 0;
          } else if (subject.delegate === this.delegate.leftSide) {
            return 1;
          } else if (subject.delegate === this.delegate.content) {
            return 2;
          } else if (subject.delegate === this.delegate.rightSide) {
            return 3;
          } else if (subject.delegate === this.delegate.footer) {
            return 4;
          } else {
            return -1;
          }
        } else if (this.delegate instanceof ScrollPane__default["default"]) {
          if (subject.delegate === this.delegate.view) {
            return 0;
          } else {
            return -1;
          }
        } else if (this.delegate instanceof SplitPane__default["default"]) {
          if (subject.delegate === this.delegate.first) {
            return 0;
          } else if (subject.delegate === this.delegate.second) {
            return 1;
          } else {
            return -1;
          }
        } else {
          return this.delegate.indexOf(subject.delegate);
        }
      }
    }
  }, {
    key: "add",
    value: function add(subject, index) {
      if (this.delegate instanceof DataGrid__default["default"] || this.delegate instanceof ColumnNode__default["default"]) {
        this.delegate.insertColumnNode(index, subject.delegate);
      } else if (this.delegate instanceof HolyGrailPane__default["default"]) {
        var children = this.children;
        children.splice(index, 0, subject);
        this.delegate.clear();
        this.delegate.header = children.length > 0 ? children[0].delegate : null;
        this.delegate.leftSide = children.length > 1 ? children[1].delegate : null;
        this.delegate.content = children.length > 2 ? children[2].delegate : null;
        this.delegate.rightSide = children.length > 3 ? children[3].delegate : null;
        this.delegate.footer = children.length > 4 ? children[4].delegate : null;
      } else if (this.delegate instanceof ScrollPane__default["default"]) {
        this.delegate.view = subject.delegate;
      } else if (this.delegate instanceof SplitPane__default["default"]) {
        var _children = this.children;

        _children.splice(index, 0, subject);

        this.delegate.clear();
        this.delegate.first = _children.length > 0 ? _children[0].delegate : null;
        this.delegate.second = _children.length > 1 ? _children[1].delegate : null;
      } else {
        this.delegate.add(subject.delegate, index);
      }
    }
  }, {
    key: "remove",
    value: function remove(index) {
      if (this.delegate instanceof DataGrid__default["default"] || this.delegate instanceof ColumnNode__default["default"]) {
        this.delegate.removeColumnNodeAt(index);
      } else if (this.delegate instanceof HolyGrailPane__default["default"]) {
        var children = this.children;
        children.splice(index, 1);
        this.delegate.header = this.delegate.leftSide = this.delegate.content = this.delegate.rightSide = this.delegate.footer = null;
        this.delegate.header = children.length > 0 ? children[0].delegate : null;
        this.delegate.leftSide = children.length > 1 ? children[1].delegate : null;
        this.delegate.content = children.length > 2 ? children[2].delegate : null;
        this.delegate.rightSide = children.length > 3 ? children[3].delegate : null;
        this.delegate.footer = children.length > 4 ? children[4].delegate : null;
      } else if (this.delegate instanceof ScrollPane__default["default"]) {
        this.delegate.view = null;
      } else if (this.delegate instanceof SplitPane__default["default"]) {
        var _children2 = this.children;

        _children2.splice(index, 1);

        this.delegate.first = this.delegate.second = null;
        this.delegate.first = _children2.length > 0 ? _children2[0].delegate : null;
        this.delegate.second = _children2.length > 1 ? _children2[1].delegate : null;
      } else {
        this.delegate.remove(index);
      }
    }
  }]);

  return WidgetWrapper;
}();

module.exports = WidgetWrapper;
